# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_ghost_pb2 as eolymp_dot_community_dot_member__ghost__pb2
from eolymp.community import member_team_pb2 as eolymp_dot_community_dot_member__team__pb2
from eolymp.community import member_user_pb2 as eolymp_dot_community_dot_member__user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a\x1c\x65olymp/annotations/mcp.proto\x1a eolymp/community/attribute.proto\x1a#eolymp/community/member_ghost.proto\x1a\"eolymp/community/member_team.proto\x1a\"eolymp/community/member_user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xca\r\n\x06Member\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x13\n\x03url\x18\x03 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x0c\x65xternal_ref\x18\x04 \x01(\t\x12\x1c\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x04rank\x18\x46 \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1a\n\nrank_lower\x18H \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x16\n\x06rating\x18G \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x15\n\x05level\x18O \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x10\n\x08inactive\x18\x0b \x01(\x08\x12\x12\n\nincomplete\x18\x14 \x01(\x08\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x0e\n\x06secret\x18( \x01(\x08\x12\x37\n\x13\x61\x63tive_period_start\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11\x61\x63tive_period_end\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\ncreated_at\x18< \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x35\n\tseated_at\x18= \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x35\n\tactive_at\x18> \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xa8\xf0\xf0\xe4\x01\x01\x12&\n\x04user\x18\x64 \x01(\x0b\x32\x16.eolymp.community.UserH\x00\x12&\n\x04team\x18\x65 \x01(\x0b\x32\x16.eolymp.community.TeamH\x00\x12(\n\x05ghost\x18\x66 \x01(\x0b\x32\x17.eolymp.community.GhostH\x00\x12\x1c\n\x0crestrictions\x18\n \x03(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x36\n\x05stats\x18\xac\x02 \x01(\x0b\x32\x1e.eolymp.community.Member.StatsB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x0f\n\x06groups\x18\xc8\x01 \x03(\t\x12\x36\n\nattributes\x18\x84\x07 \x03(\x0b\x32!.eolymp.community.Attribute.Value\x12\x39\n\x08metadata\x18\x80\x08 \x03(\x0b\x32&.eolymp.community.Member.MetadataEntry\x1a\x86\x01\n\x05\x45xtra\"}\n\x05\x46ield\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x08\n\x04RANK\x10\x01\x12\t\n\x05STATS\x10\x02\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nATTRIBUTES\x10\x04\x12\x0c\n\x08METADATA\x10\x05\x12\x10\n\x0cRESTRICTIONS\x10\x06\x12\x10\n\x0cPRIVATE_DATA\x10\x07\x1a\x9d\x04\n\x05Patch\"\x93\x04\n\x05\x46ield\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\x10\n\x0c\x45XTERNAL_REF\x10\x06\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nUNOFFICIAL\x10\x02\x12\x17\n\x13\x41\x43TIVE_PERIOD_START\x10\x07\x12\x15\n\x11\x41\x43TIVE_PERIOD_END\x10\x08\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nGROUPS_ADD\x10\x04\x12\x11\n\rGROUPS_REMOVE\x10\x05\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x64\x12\x11\n\rUSER_NICKNAME\x10\x65\x12\x0e\n\nUSER_EMAIL\x10\x66\x12\x11\n\rUSER_PASSWORD\x10g\x12\r\n\tUSER_NAME\x10h\x12\x10\n\x0cUSER_PICTURE\x10i\x12\x11\n\rUSER_BIRTHDAY\x10j\x12\x10\n\x0cUSER_COUNTRY\x10k\x12\r\n\tUSER_CITY\x10l\x12\x14\n\x10USER_PREFERENCES\x10m\x12\x1c\n\x17USER_PREFERENCES_LOCALE\x10\xbe\x01\x12\x1e\n\x19USER_PREFERENCES_TIMEZONE\x10\xbf\x01\x12\x1d\n\x18USER_PREFERENCES_RUNTIME\x10\xc0\x01\x12\x1c\n\x18USER_EMAIL_SUBSCRIPTIONS\x10n\x12\x0e\n\tTEAM_NAME\x10\xc8\x01\x12\x0f\n\nGHOST_NAME\x10\xac\x02\x12\x0f\n\nATTRIBUTES\x10\x84\x07\x12\r\n\x08METADATA\x10\x85\x07\x1ai\n\x05Stats\x12\x0e\n\x06streak\x18\n \x01(\x05\x12\x17\n\x0fproblems_solved\x18\x14 \x01(\x05\x12\x1c\n\x14submissions_accepted\x18\x1e \x01(\x05\x12\x19\n\x11submissions_total\x18) \x01(\x05\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x61\x63\x63ountB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_MEMBER_METADATAENTRY']._loaded_options = None
  _globals['_MEMBER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MEMBER'].fields_by_name['id']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['url']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['url']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['display_name']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['display_name']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rank']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rank']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rank_lower']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rank_lower']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['rating']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['rating']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['level']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['level']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['created_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['created_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['seated_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['seated_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['active_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['active_at']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['restrictions']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['restrictions']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER'].fields_by_name['stats']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['stats']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_MEMBER']._serialized_start=258
  _globals['_MEMBER']._serialized_end=1996
  _globals['_MEMBER_EXTRA']._serialized_start=1151
  _globals['_MEMBER_EXTRA']._serialized_end=1285
  _globals['_MEMBER_EXTRA_FIELD']._serialized_start=1160
  _globals['_MEMBER_EXTRA_FIELD']._serialized_end=1285
  _globals['_MEMBER_PATCH']._serialized_start=1288
  _globals['_MEMBER_PATCH']._serialized_end=1829
  _globals['_MEMBER_PATCH_FIELD']._serialized_start=1298
  _globals['_MEMBER_PATCH_FIELD']._serialized_end=1829
  _globals['_MEMBER_STATS']._serialized_start=1831
  _globals['_MEMBER_STATS']._serialized_end=1936
  _globals['_MEMBER_METADATAENTRY']._serialized_start=1938
  _globals['_MEMBER_METADATAENTRY']._serialized_end=1985
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/vendor_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/vendor_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.vendor import profile_pb2 as eolymp_dot_vendor_dot_profile__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/vendor/vendor_service.proto\x12\reolymp.vendor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/vendor/profile.proto\x1a!eolymp/wellknown/expression.proto\"\xe7\x02\n\x10ListVendorsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.vendor.ListVendorsInput.Filter\x1a\xfb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\x05\x65mail\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x07\x63ountry\x18\x05 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"I\n\x11ListVendorsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.vendor.Profile\"(\n\x13\x44\x65scribeVendorInput\x12\x11\n\tvendor_id\x18\x01 \x01(\t\"?\n\x14\x44\x65scribeVendorOutput\x12\'\n\x07profile\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Profile\"8\n\x12\x41pproveVendorInput\x12\x11\n\tvendor_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x15\n\x13\x41pproveVendorOutput\"7\n\x11RejectVendorInput\x12\x11\n\tvendor_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x14\n\x12RejectVendorOutput2\x92\x05\n\rVendorService\x12\x8c\x01\n\x0bListVendors\x12\x1f.eolymp.vendor.ListVendorsInput\x1a .eolymp.vendor.ListVendorsOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\n\x12\x08/vendors\x12\xa1\x01\n\x0e\x44\x65scribeVendor\x12\".eolymp.vendor.DescribeVendorInput\x1a#.eolymp.vendor.DescribeVendorOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x16\x12\x14/vendors/{vendor_id}\x12\xa7\x01\n\rApproveVendor\x12!.eolymp.vendor.ApproveVendorInput\x1a\".eolymp.vendor.ApproveVendorOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/vendors/{vendor_id}/approve\x12\xa3\x01\n\x0cRejectVendor\x12 .eolymp.vendor.RejectVendorInput\x1a!.eolymp.vendor.RejectVendorOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/vendors/{vendor_id}/rejectB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.vendor_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_VENDORSERVICE'].methods_by_name['ListVendors']._loaded_options = None
  _globals['_VENDORSERVICE'].methods_by_name['ListVendors']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\n\022\010/vendors'
  _globals['_VENDORSERVICE'].methods_by_name['DescribeVendor']._loaded_options = None
  _globals['_VENDORSERVICE'].methods_by_name['DescribeVendor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\026\022\024/vendors/{vendor_id}'
  _globals['_VENDORSERVICE'].methods_by_name['ApproveVendor']._loaded_options = None
  _globals['_VENDORSERVICE'].methods_by_name['ApproveVendor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\036\"\034/vendors/{vendor_id}/approve'
  _globals['_VENDORSERVICE'].methods_by_name['RejectVendor']._loaded_options = None
  _globals['_VENDORSERVICE'].methods_by_name['RejectVendor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\035\"\033/vendors/{vendor_id}/reject'
  _globals['_LISTVENDORSINPUT']._serialized_start=217
  _globals['_LISTVENDORSINPUT']._serialized_end=576
  _globals['_LISTVENDORSINPUT_FILTER']._serialized_start=325
  _globals['_LISTVENDORSINPUT_FILTER']._serialized_end=576
  _globals['_LISTVENDORSOUTPUT']._serialized_start=578
  _globals['_LISTVENDORSOUTPUT']._serialized_end=651
  _globals['_DESCRIBEVENDORINPUT']._serialized_start=653
  _globals['_DESCRIBEVENDORINPUT']._serialized_end=693
  _globals['_DESCRIBEVENDOROUTPUT']._serialized_start=695
  _globals['_DESCRIBEVENDOROUTPUT']._serialized_end=758
  _globals['_APPROVEVENDORINPUT']._serialized_start=760
  _globals['_APPROVEVENDORINPUT']._serialized_end=816
  _globals['_APPROVEVENDOROUTPUT']._serialized_start=818
  _globals['_APPROVEVENDOROUTPUT']._serialized_end=839
  _globals['_REJECTVENDORINPUT']._serialized_start=841
  _globals['_REJECTVENDORINPUT']._serialized_end=896
  _globals['_REJECTVENDOROUTPUT']._serialized_start=898
  _globals['_REJECTVENDOROUTPUT']._serialized_end=918
  _globals['_VENDORSERVICE']._serialized_start=921
  _globals['_VENDORSERVICE']._serialized_end=1579
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.commerce import address_pb2 as _address_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Order(_message.Message):
    __slots__ = ("id", "reference", "member_id", "status", "items", "billing_address", "shipping_address", "billing_same_as_shipping", "estimated_shipping_date", "currency", "total_amount", "shipping_amount", "discount_amount", "tax_amount", "tax_rate", "tax_note", "grand_total", "tracking_link", "tracking_number", "created_at", "updated_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSPECIFIED: _ClassVar[Order.Status]
        CREATED: _ClassVar[Order.Status]
        PENDING: _ClassVar[Order.Status]
        PROCESSING: _ClassVar[Order.Status]
        CANCELED: _ClassVar[Order.Status]
        SHIPPED: _ClassVar[Order.Status]
        COMPLETE: _ClassVar[Order.Status]
    UNSPECIFIED: Order.Status
    CREATED: Order.Status
    PENDING: Order.Status
    PROCESSING: Order.Status
    CANCELED: Order.Status
    SHIPPED: Order.Status
    COMPLETE: Order.Status
    class Item(_message.Message):
        __slots__ = ("id", "name", "image_url", "product_id", "variant_id", "quantity_ordered", "quantity_cancelled", "quantity_shipped", "quantity_returned", "quantity_allocated", "unit_amount", "total_amount", "discount_amount")
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
        PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
        VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_ORDERED_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_CANCELLED_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_SHIPPED_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_RETURNED_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_ALLOCATED_FIELD_NUMBER: _ClassVar[int]
        UNIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        DISCOUNT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        id: str
        name: str
        image_url: str
        product_id: str
        variant_id: str
        quantity_ordered: int
        quantity_cancelled: int
        quantity_shipped: int
        quantity_returned: int
        quantity_allocated: int
        unit_amount: int
        total_amount: int
        discount_amount: int
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., product_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., quantity_ordered: _Optional[int] = ..., quantity_cancelled: _Optional[int] = ..., quantity_shipped: _Optional[int] = ..., quantity_returned: _Optional[int] = ..., quantity_allocated: _Optional[int] = ..., unit_amount: _Optional[int] = ..., total_amount: _Optional[int] = ..., discount_amount: _Optional[int] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    BILLING_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BILLING_SAME_AS_SHIPPING_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_SHIPPING_DATE_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_RATE_FIELD_NUMBER: _ClassVar[int]
    TAX_NOTE_FIELD_NUMBER: _ClassVar[int]
    GRAND_TOTAL_FIELD_NUMBER: _ClassVar[int]
    TRACKING_LINK_FIELD_NUMBER: _ClassVar[int]
    TRACKING_NUMBER_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    reference: str
    member_id: str
    status: Order.Status
    items: _containers.RepeatedCompositeFieldContainer[Order.Item]
    billing_address: _address_pb2.Address
    shipping_address: _address_pb2.Address
    billing_same_as_shipping: bool
    estimated_shipping_date: _timestamp_pb2.Timestamp
    currency: str
    total_amount: int
    shipping_amount: int
    discount_amount: int
    tax_amount: int
    tax_rate: int
    tax_note: str
    grand_total: int
    tracking_link: str
    tracking_number: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., reference: _Optional[str] = ..., member_id: _Optional[str] = ..., status: _Optional[_Union[Order.Status, str]] = ..., items: _Optional[_Iterable[_Union[Order.Item, _Mapping]]] = ..., billing_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., shipping_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., billing_same_as_shipping: bool = ..., estimated_shipping_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., currency: _Optional[str] = ..., total_amount: _Optional[int] = ..., shipping_amount: _Optional[int] = ..., discount_amount: _Optional[int] = ..., tax_amount: _Optional[int] = ..., tax_rate: _Optional[int] = ..., tax_note: _Optional[str] = ..., grand_total: _Optional[int] = ..., tracking_link: _Optional[str] = ..., tracking_number: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/template.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/template.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/judge/template.proto\x12\x0c\x65olymp.judge\"7\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\n \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.template_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_TEMPLATE']._serialized_start=45
  _globals['_TEMPLATE']._serialized_end=100
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Certificate(_message.Message):
    __slots__ = ("id", "use", "type", "algorithm", "rsa_exponent", "rsa_modulus", "ec_curve", "ec_x", "ec_y")
    ID_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    RSA_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    RSA_MODULUS_FIELD_NUMBER: _ClassVar[int]
    EC_CURVE_FIELD_NUMBER: _ClassVar[int]
    EC_X_FIELD_NUMBER: _ClassVar[int]
    EC_Y_FIELD_NUMBER: _ClassVar[int]
    id: str
    use: str
    type: str
    algorithm: str
    rsa_exponent: str
    rsa_modulus: str
    ec_curve: str
    ec_x: str
    ec_y: str
    def __init__(self, id: _Optional[str] = ..., use: _Optional[str] = ..., type: _Optional[str] = ..., algorithm: _Optional[str] = ..., rsa_exponent: _Optional[str] = ..., rsa_modulus: _Optional[str] = ..., ec_curve: _Optional[str] = ..., ec_x: _Optional[str] = ..., ec_y: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/post_type_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/content/post_type_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.content import post_type_pb2 as eolymp_dot_content_dot_post__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/content/post_type_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/content/post_type.proto\"h\n\x15\x44\x65scribePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.content.PostType.Extra\"@\n\x16\x44\x65scribePostTypeOutput\x12&\n\x04type\x18\x01 \x01(\x0b\x32\x18.eolymp.content.PostType\"r\n\x12ListPostTypesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06locale\x18\x14 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.content.PostType.Extra\"M\n\x13ListPostTypesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.content.PostType\"=\n\x13\x43reatePostTypeInput\x12&\n\x04type\x18\x01 \x01(\x0b\x32\x18.eolymp.content.PostType\"\'\n\x14\x43reatePostTypeOutput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\"N\n\x13UpdatePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0b\x32\x18.eolymp.content.PostType\"\x16\n\x14UpdatePostTypeOutput\"&\n\x13\x44\x65letePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65letePostTypeOutput2\xb6\x06\n\x0fPostTypeService\x12\x90\x01\n\x10\x44\x65scribePostType\x12%.eolymp.content.DescribePostTypeInput\x1a&.eolymp.content.DescribePostTypeOutput\"-\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x17\x12\x15/post-types/{type_id}\x12|\n\rListPostTypes\x12\".eolymp.content.ListPostTypesInput\x1a#.eolymp.content.ListPostTypesOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/post-types\x12\x9e\x01\n\x0e\x43reatePostType\x12#.eolymp.content.CreatePostTypeInput\x1a$.eolymp.content.CreatePostTypeOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ontent:post-type:write\x82\xd3\xe4\x93\x02\r\"\x0b/post-types\x12\xa8\x01\n\x0eUpdatePostType\x12#.eolymp.content.UpdatePostTypeInput\x1a$.eolymp.content.UpdatePostTypeOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ontent:post-type:write\x82\xd3\xe4\x93\x02\x17\x1a\x15/post-types/{type_id}\x12\xa8\x01\n\x0e\x44\x65letePostType\x12#.eolymp.content.DeletePostTypeInput\x1a$.eolymp.content.DeletePostTypeOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ontent:post-type:write\x82\xd3\xe4\x93\x02\x17*\x15/post-types/{type_id}\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.post_type_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_POSTTYPESERVICE']._loaded_options = None
  _globals['_POSTTYPESERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_POSTTYPESERVICE'].methods_by_name['DescribePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['DescribePostType']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\027\022\025/post-types/{type_id}'
  _globals['_POSTTYPESERVICE'].methods_by_name['ListPostTypes']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['ListPostTypes']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/post-types'
  _globals['_POSTTYPESERVICE'].methods_by_name['CreatePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['CreatePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\033\212\343\n\027content:post-type:write\202\323\344\223\002\r\"\013/post-types'
  _globals['_POSTTYPESERVICE'].methods_by_name['UpdatePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['UpdatePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\033\212\343\n\027content:post-type:write\202\323\344\223\002\027\032\025/post-types/{type_id}'
  _globals['_POSTTYPESERVICE'].methods_by_name['DeletePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['DeletePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\033\212\343\n\027content:post-type:write\202\323\344\223\002\027*\025/post-types/{type_id}'
  _globals['_DESCRIBEPOSTTYPEINPUT']._serialized_start=225
  _globals['_DESCRIBEPOSTTYPEINPUT']._serialized_end=329
  _globals['_DESCRIBEPOSTTYPEOUTPUT']._serialized_start=331
  _globals['_DESCRIBEPOSTTYPEOUTPUT']._serialized_end=395
  _globals['_LISTPOSTTYPESINPUT']._serialized_start=397
  _globals['_LISTPOSTTYPESINPUT']._serialized_end=511
  _globals['_LISTPOSTTYPESOUTPUT']._serialized_start=513
  _globals['_LISTPOSTTYPESOUTPUT']._serialized_end=590
  _globals['_CREATEPOSTTYPEINPUT']._serialized_start=592
  _globals['_CREATEPOSTTYPEINPUT']._serialized_end=653
  _globals['_CREATEPOSTTYPEOUTPUT']._serialized_start=655
  _globals['_CREATEPOSTTYPEOUTPUT']._serialized_end=694
  _globals['_UPDATEPOSTTYPEINPUT']._serialized_start=696
  _globals['_UPDATEPOSTTYPEINPUT']._serialized_end=774
  _globals['_UPDATEPOSTTYPEOUTPUT']._serialized_start=776
  _globals['_UPDATEPOSTTYPEOUTPUT']._serialized_end=798
  _globals['_DELETEPOSTTYPEINPUT']._serialized_start=800
  _globals['_DELETEPOSTTYPEINPUT']._serialized_end=838
  _globals['_DELETEPOSTTYPEOUTPUT']._serialized_start=840
  _globals['_DELETEPOSTTYPEOUTPUT']._serialized_end=862
  _globals['_POSTTYPESERVICE']._serialized_start=865
  _globals['_POSTTYPESERVICE']._serialized_end=1687
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class StatementServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateStatement(self, request, **kwargs):
        path = "/statements"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateStatementOutput"),
            **kwargs,
        )

    def UpdateStatement(self, request, **kwargs):
        path = "/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.statement_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateStatementOutput"),
            **kwargs,
        )

    def DeleteStatement(self, request, **kwargs):
        path = "/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.statement_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteStatementOutput"),
            **kwargs,
        )

    def DescribeStatement(self, request, **kwargs):
        path = "/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.statement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeStatementOutput"),
            **kwargs,
        )

    def LookupStatement(self, request, **kwargs):
        path = "/translate"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.LookupStatementOutput"),
            **kwargs,
        )

    def PreviewStatement(self, request, **kwargs):
        path = "/renders"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.PreviewStatementOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        path = "/statements"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListStatementsOutput"),
            **kwargs,
        )

    def TranslateStatements(self, request, **kwargs):
        path = "/statements:translate"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.TranslateStatementsOutput"),
            **kwargs,
        )

    def ExportStatement(self, request, **kwargs):
        path = "/statements/"+urllib.parse.quote(request.statement_id)+"/export"

        # Cleanup URL parameters to avoid any ambiguity
        request.statement_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ExportStatementOutput"),
            **kwargs,
        )

    def ListStatementVersions(self, request, **kwargs):
        path = "/statements/"+urllib.parse.quote(request.statement_id)+"/versions"

        # Cleanup URL parameters to avoid any ambiguity
        request.statement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListStatementVersionsOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/payment_method.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/payment_method.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/vendor/payment_method.proto\x12\reolymp.vendor\"\xc3\x05\n\rPaymentMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\x08\x12\x0f\n\x07\x63ountry\x18\x04 \x01(\t\x12\x42\n\rsepa_transfer\x18\x65 \x01(\x0b\x32).eolymp.vendor.PaymentMethod.TransferSEPAH\x00\x12\x44\n\x0eswift_transfer\x18\x66 \x01(\x0b\x32*.eolymp.vendor.PaymentMethod.TransferSWIFTH\x00\x12\x46\n\x0f\x63rypto_transfer\x18g \x01(\x0b\x32+.eolymp.vendor.PaymentMethod.TransferCryptoH\x00\x12\x42\n\rneft_transfer\x18h \x01(\x0b\x32).eolymp.vendor.PaymentMethod.TransferNEFTH\x00\x12@\n\x0c\x61\x63h_transfer\x18i \x01(\x0b\x32(.eolymp.vendor.PaymentMethod.TransferACHH\x00\x1a\x1c\n\x0cTransferSEPA\x12\x0c\n\x04iban\x18\x01 \x01(\t\x1a\x39\n\rTransferSWIFT\x12\x10\n\x08\x62ic_code\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x02 \x01(\t\x1a\x39\n\x0cTransferNEFT\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\t\x12\x11\n\tifsc_code\x18\x02 \x01(\t\x1a=\n\x0bTransferACH\x12\x16\n\x0erouting_number\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x02 \x01(\t\x1a\x41\n\x0eTransferCrypto\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x08\n\x06methodB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.payment_method_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_PAYMENTMETHOD']._serialized_start=54
  _globals['_PAYMENTMETHOD']._serialized_end=761
  _globals['_PAYMENTMETHOD_TRANSFERSEPA']._serialized_start=475
  _globals['_PAYMENTMETHOD_TRANSFERSEPA']._serialized_end=503
  _globals['_PAYMENTMETHOD_TRANSFERSWIFT']._serialized_start=505
  _globals['_PAYMENTMETHOD_TRANSFERSWIFT']._serialized_end=562
  _globals['_PAYMENTMETHOD_TRANSFERNEFT']._serialized_start=564
  _globals['_PAYMENTMETHOD_TRANSFERNEFT']._serialized_end=621
  _globals['_PAYMENTMETHOD_TRANSFERACH']._serialized_start=623
  _globals['_PAYMENTMETHOD_TRANSFERACH']._serialized_end=684
  _globals['_PAYMENTMETHOD_TRANSFERCRYPTO']._serialized_start=686
  _globals['_PAYMENTMETHOD_TRANSFERCRYPTO']._serialized_end=751
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/invoice.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/invoice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/vendor/invoice.proto\x12\reolymp.vendor\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x06\n\x07Invoice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\n \x01(\t\x12-\n\x06status\x18\x0b \x01(\x0e\x32\x1d.eolymp.vendor.Invoice.Status\x12\x15\n\rstatus_reason\x18\x0c \x01(\t\x12\x11\n\tvendor_id\x18\r \x01(\t\x12\x19\n\x11payment_method_id\x18\x0e \x01(\t\x12\x30\n\x0cinvoice_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64ue_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x05lines\x18\x05 \x03(\x0b\x32\x1b.eolymp.vendor.Invoice.Line\x12\x17\n\x0fsubtotal_amount\x18\x06 \x01(\x05\x12\x12\n\ntax_amount\x18\x07 \x01(\x05\x12\x13\n\x0bgrand_total\x18\x08 \x01(\x05\x12\x14\n\x0c\x64ocument_url\x18\t \x01(\t\x12.\n\ncreated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x04Line\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x13\n\x0btotal_price\x18\x04 \x01(\x05\x1a|\n\x05Patch\"s\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x0c\n\x08\x43URRENCY\x10\x05\x12\x10\n\x0cINVOICE_DATE\x10\x02\x12\x0c\n\x08\x44UE_DATE\x10\x03\x12\t\n\x05LINES\x10\x04\x12\x12\n\x0ePAYMENT_METHOD\x10\x06\"Z\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0c\n\x08\x41PPROVED\x10\x03\x12\x08\n\x04PAID\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.invoice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_INVOICE']._serialized_start=80
  _globals['_INVOICE']._serialized_end=868
  _globals['_INVOICE_LINE']._serialized_start=577
  _globals['_INVOICE_LINE']._serialized_end=650
  _globals['_INVOICE_PATCH']._serialized_start=652
  _globals['_INVOICE_PATCH']._serialized_end=776
  _globals['_INVOICE_PATCH_FIELD']._serialized_start=661
  _globals['_INVOICE_PATCH_FIELD']._serialized_end=776
  _globals['_INVOICE_STATUS']._serialized_start=778
  _globals['_INVOICE_STATUS']._serialized_end=868
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.vendor import payment_method_pb2 as _payment_method_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePaymentMethodInput(_message.Message):
    __slots__ = ("method",)
    METHOD_FIELD_NUMBER: _ClassVar[int]
    method: _payment_method_pb2.PaymentMethod
    def __init__(self, method: _Optional[_Union[_payment_method_pb2.PaymentMethod, _Mapping]] = ...) -> None: ...

class CreatePaymentMethodOutput(_message.Message):
    __slots__ = ("method_id",)
    METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    method_id: str
    def __init__(self, method_id: _Optional[str] = ...) -> None: ...

class UpdatePaymentMethodInput(_message.Message):
    __slots__ = ("method_id", "method")
    METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    method_id: str
    method: _payment_method_pb2.PaymentMethod
    def __init__(self, method_id: _Optional[str] = ..., method: _Optional[_Union[_payment_method_pb2.PaymentMethod, _Mapping]] = ...) -> None: ...

class UpdatePaymentMethodOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePaymentMethodInput(_message.Message):
    __slots__ = ("method_id",)
    METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    method_id: str
    def __init__(self, method_id: _Optional[str] = ...) -> None: ...

class DeletePaymentMethodOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribePaymentMethodInput(_message.Message):
    __slots__ = ("method_id",)
    METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    method_id: str
    def __init__(self, method_id: _Optional[str] = ...) -> None: ...

class DescribePaymentMethodOutput(_message.Message):
    __slots__ = ("method",)
    METHOD_FIELD_NUMBER: _ClassVar[int]
    method: _payment_method_pb2.PaymentMethod
    def __init__(self, method: _Optional[_Union[_payment_method_pb2.PaymentMethod, _Mapping]] = ...) -> None: ...

class ListPaymentMethodsInput(_message.Message):
    __slots__ = ("after", "size", "offset", "search", "filters")
    class Filter(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    after: str
    size: int
    offset: int
    search: str
    filters: ListPaymentMethodsInput.Filter
    def __init__(self, after: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListPaymentMethodsInput.Filter, _Mapping]] = ...) -> None: ...

class ListPaymentMethodsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_payment_method_pb2.PaymentMethod]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_payment_method_pb2.PaymentMethod, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/problem.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/problem.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.atlas import form_pb2 as eolymp_dot_atlas_dot_form__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/problem.proto\x12\x0c\x65olymp.judge\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\x17\x65olymp/atlas/form.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a#eolymp/atlas/testing_feedback.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x15\x65olymp/ecm/node.proto\"\xb7\n\n\x07Problem\x12\x16\n\ncontest_id\x18\x05 \x01(\tB\x02\x18\x01\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x03url\x18\x06 \x01(\tB\x06\xb0\xf0\xf0\xe4\x01\x01\x12(\n\x04type\x18\x17 \x01(\x0e\x32\x1a.eolymp.atlas.Problem.Type\x12\x30\n\x05index\x18\x02 \x01(\rB!\xa2\xf0\xf0\xe4\x01\x1bproblem position in contest\x12\x38\n\x07\x62\x61se_id\x18\x04 \x01(\tB\'\xa2\xf0\xf0\xe4\x01!problem ID in the problem archive\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\n \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x83\x01\n\x15score_by_best_testset\x18\xd2\x01 \x01(\x08\x42\x63\xa2\xf0\xf0\xe4\x01]problem score is calculated as sum of best score in each testset (best among all submissions)\x12<\n\ntime_limit\x18\xc8\x01 \x01(\rB\'\x18\x01\xa2\xf0\xf0\xe4\x01\x1fwall-time limit in milliseconds\x12@\n\tcpu_limit\x18\xcc\x01 \x01(\rB,\x18\x01\xa2\xf0\xf0\xe4\x01$cpu usage time limit in milliseconds\x12<\n\x0cmemory_limit\x18\xc9\x01 \x01(\x04\x42%\x18\x01\xa2\xf0\xf0\xe4\x01\x1druntime memory limit in bytes\x12\"\n\x0f\x66ile_size_limit\x18\xca\x01 \x01(\x04\x42\x08\x18\x01\xb0\xf0\xf0\xe4\x01\x01\x12M\n\x0csubmit_limit\x18\xcb\x01 \x01(\rB6\x18\x01\xa2\xf0\xf0\xe4\x01.limit in number of submissions per participant\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x36\n\x0b\x63onstraints\x18\x1e \x01(\x0b\x32!.eolymp.atlas.Problem.Constraints\x12\x10\n\x08language\x18\x14 \x01(\t\x12\r\n\x05title\x18\x15 \x01(\t\x12S\n\x07\x63ontent\x18\x16 \x01(\x0b\x32\x13.eolymp.ecm.ContentB-\xa2\xf0\xf0\xe4\x01\'problem statement in requested language\x12G\n\rdownload_link\x18\x18 \x01(\tB0\xa2\xf0\xf0\xe4\x01*a link to download statement in PDF format\x12\x11\n\tlanguages\x18\x19 \x03(\t\x12+\n\x0fsubmission_form\x18= \x01(\x0b\x32\x12.eolymp.atlas.Form\x12/\n\x08\x65xamples\x18< \x03(\x0b\x32\x1d.eolymp.atlas.Problem.Example\x1a\x64\n\tStatement\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12!\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x10.eolymp.ecm.Node\x12\x15\n\rdownload_link\x18\x06 \x01(\t\x1a\\\n\x04Test\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x65xample\x18\x02 \x01(\x08\x12\x11\n\tinput_url\x18\r \x01(\t\x12\x12\n\nanswer_url\x18\x0e \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x02\x1a\x34\n\nAttachment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04link\x18\x04 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.problem_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PROBLEM'].fields_by_name['contest_id']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['contest_id']._serialized_options = b'\030\001'
  _globals['_PROBLEM'].fields_by_name['url']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['url']._serialized_options = b'\260\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['index']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['index']._serialized_options = b'\242\360\360\344\001\033problem position in contest'
  _globals['_PROBLEM'].fields_by_name['base_id']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['base_id']._serialized_options = b'\242\360\360\344\001!problem ID in the problem archive'
  _globals['_PROBLEM'].fields_by_name['score_by_best_testset']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['score_by_best_testset']._serialized_options = b'\242\360\360\344\001]problem score is calculated as sum of best score in each testset (best among all submissions)'
  _globals['_PROBLEM'].fields_by_name['time_limit']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['time_limit']._serialized_options = b'\030\001\242\360\360\344\001\037wall-time limit in milliseconds'
  _globals['_PROBLEM'].fields_by_name['cpu_limit']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['cpu_limit']._serialized_options = b'\030\001\242\360\360\344\001$cpu usage time limit in milliseconds'
  _globals['_PROBLEM'].fields_by_name['memory_limit']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['memory_limit']._serialized_options = b'\030\001\242\360\360\344\001\035runtime memory limit in bytes'
  _globals['_PROBLEM'].fields_by_name['file_size_limit']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['file_size_limit']._serialized_options = b'\030\001\260\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['submit_limit']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['submit_limit']._serialized_options = b'\030\001\242\360\360\344\001.limit in number of submissions per participant'
  _globals['_PROBLEM'].fields_by_name['content']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['content']._serialized_options = b'\242\360\360\344\001\'problem statement in requested language'
  _globals['_PROBLEM'].fields_by_name['download_link']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['download_link']._serialized_options = b'\242\360\360\344\001*a link to download statement in PDF format'
  _globals['_PROBLEM']._serialized_start=214
  _globals['_PROBLEM']._serialized_end=1549
  _globals['_PROBLEM_STATEMENT']._serialized_start=1301
  _globals['_PROBLEM_STATEMENT']._serialized_end=1401
  _globals['_PROBLEM_TEST']._serialized_start=1403
  _globals['_PROBLEM_TEST']._serialized_end=1495
  _globals['_PROBLEM_ATTACHMENT']._serialized_start=1497
  _globals['_PROBLEM_ATTACHMENT']._serialized_end=1549
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ClientServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def ListClients(self, request, **kwargs):
        path = "/auth/clients"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.ListClientsOutput"),
            **kwargs,
        )

    def DescribeClient(self, request, **kwargs):
        path = "/auth/clients/"+urllib.parse.quote(request.client_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.client_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.DescribeClientOutput"),
            **kwargs,
        )

    def CreateClient(self, request, **kwargs):
        path = "/auth/clients"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.CreateClientOutput"),
            **kwargs,
        )

    def UpdateClient(self, request, **kwargs):
        path = "/auth/clients/"+urllib.parse.quote(request.client_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.client_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.UpdateClientOutput"),
            **kwargs,
        )

    def DeleteClient(self, request, **kwargs):
        path = "/auth/clients/"+urllib.parse.quote(request.client_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.client_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.DeleteClientOutput"),
            **kwargs,
        )

    def ResetClientSecret(self, request, **kwargs):
        path = "/auth/clients/"+urllib.parse.quote(request.client_id)+"/reset-secret"

        # Cleanup URL parameters to avoid any ambiguity
        request.client_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.ResetClientSecretOutput"),
            **kwargs,
        )

    def RegisterClient(self, request, **kwargs):
        path = "/auth/clients:register"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.auth.RegisterClientOutput"),
            **kwargs,
        )




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PaymentMethod(_message.Message):
    __slots__ = ("id", "name", "default", "country", "sepa_transfer", "swift_transfer", "crypto_transfer", "neft_transfer", "ach_transfer")
    class TransferSEPA(_message.Message):
        __slots__ = ("iban",)
        IBAN_FIELD_NUMBER: _ClassVar[int]
        iban: str
        def __init__(self, iban: _Optional[str] = ...) -> None: ...
    class TransferSWIFT(_message.Message):
        __slots__ = ("bic_code", "account_number")
        BIC_CODE_FIELD_NUMBER: _ClassVar[int]
        ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
        bic_code: str
        account_number: str
        def __init__(self, bic_code: _Optional[str] = ..., account_number: _Optional[str] = ...) -> None: ...
    class TransferNEFT(_message.Message):
        __slots__ = ("account_number", "ifsc_code")
        ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
        IFSC_CODE_FIELD_NUMBER: _ClassVar[int]
        account_number: str
        ifsc_code: str
        def __init__(self, account_number: _Optional[str] = ..., ifsc_code: _Optional[str] = ...) -> None: ...
    class TransferACH(_message.Message):
        __slots__ = ("routing_number", "account_number")
        ROUTING_NUMBER_FIELD_NUMBER: _ClassVar[int]
        ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
        routing_number: str
        account_number: str
        def __init__(self, routing_number: _Optional[str] = ..., account_number: _Optional[str] = ...) -> None: ...
    class TransferCrypto(_message.Message):
        __slots__ = ("token", "network", "address")
        TOKEN_FIELD_NUMBER: _ClassVar[int]
        NETWORK_FIELD_NUMBER: _ClassVar[int]
        ADDRESS_FIELD_NUMBER: _ClassVar[int]
        token: str
        network: str
        address: str
        def __init__(self, token: _Optional[str] = ..., network: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    SEPA_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    SWIFT_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    CRYPTO_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    NEFT_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    ACH_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    default: bool
    country: str
    sepa_transfer: PaymentMethod.TransferSEPA
    swift_transfer: PaymentMethod.TransferSWIFT
    crypto_transfer: PaymentMethod.TransferCrypto
    neft_transfer: PaymentMethod.TransferNEFT
    ach_transfer: PaymentMethod.TransferACH
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., default: bool = ..., country: _Optional[str] = ..., sepa_transfer: _Optional[_Union[PaymentMethod.TransferSEPA, _Mapping]] = ..., swift_transfer: _Optional[_Union[PaymentMethod.TransferSWIFT, _Mapping]] = ..., crypto_transfer: _Optional[_Union[PaymentMethod.TransferCrypto, _Mapping]] = ..., neft_transfer: _Optional[_Union[PaymentMethod.TransferNEFT, _Mapping]] = ..., ach_transfer: _Optional[_Union[PaymentMethod.TransferACH, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/geolocation/geolocation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/geolocation/geolocation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,eolymp/geolocation/geolocation_service.proto\x12\x12\x65olymp.geolocation\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"8\n\x12LookupAddressInput\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x8d\x01\n\x13LookupAddressOutput\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12\x10\n\x08postcode\x18\x05 \x01(\t\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t2\xc7\x01\n\x12GeolocationService\x12\xb0\x01\n\rLookupAddress\x12&.eolymp.geolocation.LookupAddressInput\x1a\'.eolymp.geolocation.LookupAddressOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16geolocation:enum:write\x82\xd3\xe4\x93\x02\x1b\x12\x19/geolocation/{ip_address}B9Z7github.com/eolymp/go-sdk/eolymp/geolocation;geolocationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.geolocation.geolocation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/geolocation;geolocation'
  _globals['_GEOLOCATIONSERVICE'].methods_by_name['LookupAddress']._loaded_options = None
  _globals['_GEOLOCATIONSERVICE'].methods_by_name['LookupAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n2\202\343\n\032\212\343\n\026geolocation:enum:write\202\323\344\223\002\033\022\031/geolocation/{ip_address}'
  _globals['_LOOKUPADDRESSINPUT']._serialized_start=167
  _globals['_LOOKUPADDRESSINPUT']._serialized_end=223
  _globals['_LOOKUPADDRESSOUTPUT']._serialized_start=226
  _globals['_LOOKUPADDRESSOUTPUT']._serialized_end=367
  _globals['_GEOLOCATIONSERVICE']._serialized_start=370
  _globals['_GEOLOCATIONSERVICE']._serialized_end=569
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.mail import email_type_pb2 as _email_type_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Newsletter(_message.Message):
    __slots__ = ("id", "type", "created_at", "scheduled_at", "name", "subject", "content", "recipients_count", "pending_count", "sent_count", "error_count")
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[Newsletter.Patch.Field]
            TYPE: _ClassVar[Newsletter.Patch.Field]
            NAME: _ClassVar[Newsletter.Patch.Field]
            SUBJECT: _ClassVar[Newsletter.Patch.Field]
            CONTENT: _ClassVar[Newsletter.Patch.Field]
            LOCALE: _ClassVar[Newsletter.Patch.Field]
            SCHEDULED_AT: _ClassVar[Newsletter.Patch.Field]
        UNKNOWN: Newsletter.Patch.Field
        TYPE: Newsletter.Patch.Field
        NAME: Newsletter.Patch.Field
        SUBJECT: Newsletter.Patch.Field
        CONTENT: Newsletter.Patch.Field
        LOCALE: Newsletter.Patch.Field
        SCHEDULED_AT: Newsletter.Patch.Field
        def __init__(self) -> None: ...
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_EXTRA: _ClassVar[Newsletter.Extra.Field]
            CONTENT_VALUE: _ClassVar[Newsletter.Extra.Field]
            CONTENT_RENDER: _ClassVar[Newsletter.Extra.Field]
        UNKNOWN_EXTRA: Newsletter.Extra.Field
        CONTENT_VALUE: Newsletter.Extra.Field
        CONTENT_RENDER: Newsletter.Extra.Field
        def __init__(self) -> None: ...
    class Translation(_message.Message):
        __slots__ = ("id", "locale", "subject", "content", "automatic")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        SUBJECT_FIELD_NUMBER: _ClassVar[int]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        id: str
        locale: str
        subject: str
        content: _content_pb2.Content
        automatic: bool
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., automatic: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    SCHEDULED_AT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_COUNT_FIELD_NUMBER: _ClassVar[int]
    PENDING_COUNT_FIELD_NUMBER: _ClassVar[int]
    SENT_COUNT_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: _email_type_pb2.EmailType
    created_at: _timestamp_pb2.Timestamp
    scheduled_at: _timestamp_pb2.Timestamp
    name: str
    subject: str
    content: _content_pb2.Content
    recipients_count: int
    pending_count: int
    sent_count: int
    error_count: int
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[_email_type_pb2.EmailType, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., scheduled_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., name: _Optional[str] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., recipients_count: _Optional[int] = ..., pending_count: _Optional[int] = ..., sent_count: _Optional[int] = ..., error_count: _Optional[int] = ...) -> None: ...



import datetime

from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Suggestion(_message.Message):
    __slots__ = ("id", "status", "version", "member_id", "contribution", "created_at", "updated_at", "classification", "statement_change", "editorial_change")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Suggestion.Status]
        PENDING: _ClassVar[Suggestion.Status]
        IN_REVIEW: _ClassVar[Suggestion.Status]
        APPROVED: _ClassVar[Suggestion.Status]
        REJECTED: _ClassVar[Suggestion.Status]
    UNKNOWN_STATUS: Suggestion.Status
    PENDING: Suggestion.Status
    IN_REVIEW: Suggestion.Status
    APPROVED: Suggestion.Status
    REJECTED: Suggestion.Status
    class Classification(_message.Message):
        __slots__ = ("topics", "difficulty")
        TOPICS_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        topics: _containers.RepeatedScalarFieldContainer[str]
        difficulty: int
        def __init__(self, topics: _Optional[_Iterable[str]] = ..., difficulty: _Optional[int] = ...) -> None: ...
    class StatementChange(_message.Message):
        __slots__ = ("locale", "title", "statement")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        STATEMENT_FIELD_NUMBER: _ClassVar[int]
        locale: str
        title: str
        statement: _content_pb2.Content
        def __init__(self, locale: _Optional[str] = ..., title: _Optional[str] = ..., statement: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    class EditorialChange(_message.Message):
        __slots__ = ("locale", "editorial")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        EDITORIAL_FIELD_NUMBER: _ClassVar[int]
        locale: str
        editorial: _content_pb2.Content
        def __init__(self, locale: _Optional[str] = ..., editorial: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRIBUTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_CHANGE_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_CHANGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: Suggestion.Status
    version: int
    member_id: str
    contribution: int
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    classification: Suggestion.Classification
    statement_change: Suggestion.StatementChange
    editorial_change: Suggestion.EditorialChange
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Suggestion.Status, str]] = ..., version: _Optional[int] = ..., member_id: _Optional[str] = ..., contribution: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., classification: _Optional[_Union[Suggestion.Classification, _Mapping]] = ..., statement_change: _Optional[_Union[Suggestion.StatementChange, _Mapping]] = ..., editorial_change: _Optional[_Union[Suggestion.EditorialChange, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.vendor import invoice_pb2 as _invoice_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListInvoicesInput(_message.Message):
    __slots__ = ("offset", "size", "after", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "number", "status", "vendor_id")
        ID_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        number: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        vendor_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., number: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., vendor_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    after: str
    filters: ListInvoicesInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., after: _Optional[str] = ..., filters: _Optional[_Union[ListInvoicesInput.Filter, _Mapping]] = ...) -> None: ...

class ListInvoicesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_invoice_pb2.Invoice]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_invoice_pb2.Invoice, _Mapping]]] = ...) -> None: ...

class DescribeInvoiceInput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class DescribeInvoiceOutput(_message.Message):
    __slots__ = ("invoice",)
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class CreateInvoiceInput(_message.Message):
    __slots__ = ("invoice",)
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class CreateInvoiceOutput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class UpdateInvoiceInput(_message.Message):
    __slots__ = ("patch", "invoice_id", "invoice")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_invoice_pb2.Invoice.Patch.Field]
    invoice_id: str
    invoice: _invoice_pb2.Invoice
    def __init__(self, patch: _Optional[_Iterable[_Union[_invoice_pb2.Invoice.Patch.Field, str]]] = ..., invoice_id: _Optional[str] = ..., invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class UpdateInvoiceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteInvoiceInput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class DeleteInvoiceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UploadInvoiceDocumentInput(_message.Message):
    __slots__ = ("invoice_id", "filename", "data")
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    filename: str
    data: bytes
    def __init__(self, invoice_id: _Optional[str] = ..., filename: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadInvoiceDocumentOutput(_message.Message):
    __slots__ = ("document_url",)
    DOCUMENT_URL_FIELD_NUMBER: _ClassVar[int]
    document_url: str
    def __init__(self, document_url: _Optional[str] = ...) -> None: ...

class ApproveInvoiceInput(_message.Message):
    __slots__ = ("invoice_id", "comment")
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    comment: str
    def __init__(self, invoice_id: _Optional[str] = ..., comment: _Optional[str] = ...) -> None: ...

class ApproveInvoiceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SubmitInvoiceInput(_message.Message):
    __slots__ = ("invoice_id",)
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class SubmitInvoiceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RejectInvoiceInput(_message.Message):
    __slots__ = ("invoice_id", "comment")
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    comment: str
    def __init__(self, invoice_id: _Optional[str] = ..., comment: _Optional[str] = ...) -> None: ...

class RejectInvoiceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import namespace_pb2 as _namespace_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import problem_pb2 as _problem_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from eolymp.atlas import version_pb2 as _version_pb2
from eolymp.runtime import runtime_pb2 as _runtime_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProblemChangedEvent(_message.Message):
    __slots__ = ("before", "after", "version")
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    before: _problem_pb2.Problem
    after: _problem_pb2.Problem
    version: _version_pb2.Version
    def __init__(self, before: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ..., after: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ..., version: _Optional[_Union[_version_pb2.Version, _Mapping]] = ...) -> None: ...

class CreateProblemInput(_message.Message):
    __slots__ = ("problem", "statement")
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    problem: _problem_pb2.Problem
    statement: _statement_pb2.Statement
    def __init__(self, problem: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ..., statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class CreateProblemOutput(_message.Message):
    __slots__ = ("problem_id",)
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class DeleteProblemInput(_message.Message):
    __slots__ = ("problem_id",)
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class DeleteProblemOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeProblemInput(_message.Message):
    __slots__ = ("problem_id", "locale", "extra")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_problem_pb2.Problem.Extra.Field]
    def __init__(self, problem_id: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_problem_pb2.Problem.Extra.Field, str]]] = ...) -> None: ...

class DescribeProblemOutput(_message.Message):
    __slots__ = ("problem",)
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    problem: _problem_pb2.Problem
    def __init__(self, problem: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...

class ListProblemsInput(_message.Message):
    __slots__ = ("offset", "size", "search", "filters", "sort", "order", "locale", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListProblemsInput.Sortable]
        RECENT: _ClassVar[ListProblemsInput.Sortable]
        POPULAR: _ClassVar[ListProblemsInput.Sortable]
    DEFAULT: ListProblemsInput.Sortable
    RECENT: ListProblemsInput.Sortable
    POPULAR: ListProblemsInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "topic_id", "is_visible", "is_private", "number", "difficulty", "status", "score", "is_bookmarked")
        ID_FIELD_NUMBER: _ClassVar[int]
        TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
        IS_VISIBLE_FIELD_NUMBER: _ClassVar[int]
        IS_PRIVATE_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        IS_BOOKMARKED_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        topic_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        is_visible: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        is_private: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        number: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        difficulty: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        score: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionFloat]
        is_bookmarked: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., topic_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., is_visible: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., is_private: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., number: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., difficulty: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., score: _Optional[_Iterable[_Union[_expression_pb2.ExpressionFloat, _Mapping]]] = ..., is_bookmarked: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    search: str
    filters: ListProblemsInput.Filter
    sort: ListProblemsInput.Sortable
    order: _direction_pb2.Direction
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_problem_pb2.Problem.Extra.Field]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListProblemsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListProblemsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_problem_pb2.Problem.Extra.Field, str]]] = ...) -> None: ...

class ListProblemsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_problem_pb2.Problem]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_problem_pb2.Problem, _Mapping]]] = ...) -> None: ...

class UpdateVisibilityInput(_message.Message):
    __slots__ = ("problem_id", "visible")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    visible: bool
    def __init__(self, problem_id: _Optional[str] = ..., visible: bool = ...) -> None: ...

class UpdateVisibilityOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdatePrivacyInput(_message.Message):
    __slots__ = ("problem_id", "private")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    private: bool
    def __init__(self, problem_id: _Optional[str] = ..., private: bool = ...) -> None: ...

class UpdatePrivacyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateProblemInput(_message.Message):
    __slots__ = ("patch", "problem_id", "problem")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_problem_pb2.Problem.Patch.Field]
    problem_id: str
    problem: _problem_pb2.Problem
    def __init__(self, patch: _Optional[_Iterable[_Union[_problem_pb2.Problem.Patch.Field, str]]] = ..., problem_id: _Optional[str] = ..., problem: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...

class UpdateProblemOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SyncProblemInput(_message.Message):
    __slots__ = ("problem_id",)
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class SyncProblemOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListVersionsInput(_message.Message):
    __slots__ = ("problem_id", "offset", "size", "after", "filters")
    class Filter(_message.Message):
        __slots__ = ("number", "created_by", "created_at", "change_op", "change_path")
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        CREATED_BY_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        CHANGE_OP_FIELD_NUMBER: _ClassVar[int]
        CHANGE_PATH_FIELD_NUMBER: _ClassVar[int]
        number: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        created_by: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        created_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        change_op: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        change_path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, number: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., created_by: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., created_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., change_op: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., change_path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    offset: int
    size: int
    after: str
    filters: ListVersionsInput.Filter
    def __init__(self, problem_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., after: _Optional[str] = ..., filters: _Optional[_Union[ListVersionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListVersionsOutput(_message.Message):
    __slots__ = ("total", "items", "next_page_cursor")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_version_pb2.Version]
    next_page_cursor: str
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_version_pb2.Version, _Mapping]]] = ..., next_page_cursor: _Optional[str] = ...) -> None: ...

class VoteProblemInput(_message.Message):
    __slots__ = ("problem_id", "vote")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    vote: int
    def __init__(self, problem_id: _Optional[str] = ..., vote: _Optional[int] = ...) -> None: ...

class VoteProblemOutput(_message.Message):
    __slots__ = ("vote_count",)
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    vote_count: int
    def __init__(self, vote_count: _Optional[int] = ...) -> None: ...

class ListRuntimesInput(_message.Message):
    __slots__ = ("problem_id",)
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class ListRuntimesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_runtime_pb2.Runtime]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_runtime_pb2.Runtime, _Mapping]]] = ...) -> None: ...

class ExportProblemInput(_message.Message):
    __slots__ = ("problem_id", "version")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    version: int
    def __init__(self, problem_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class ExportProblemOutput(_message.Message):
    __slots__ = ("snapshot_url",)
    SNAPSHOT_URL_FIELD_NUMBER: _ClassVar[int]
    snapshot_url: str
    def __init__(self, snapshot_url: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Form(_message.Message):
    __slots__ = ("fields",)
    class Field(_message.Message):
        __slots__ = ("name", "label", "type", "code", "file")
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_TYPE: _ClassVar[Form.Field.Type]
            CODE: _ClassVar[Form.Field.Type]
            FILE: _ClassVar[Form.Field.Type]
        UNKNOWN_TYPE: Form.Field.Type
        CODE: Form.Field.Type
        FILE: Form.Field.Type
        class Code(_message.Message):
            __slots__ = ("runtimes", "max_attachments", "attachment_max_size", "attachment_types", "attachment_extensions")
            RUNTIMES_FIELD_NUMBER: _ClassVar[int]
            MAX_ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
            ATTACHMENT_MAX_SIZE_FIELD_NUMBER: _ClassVar[int]
            ATTACHMENT_TYPES_FIELD_NUMBER: _ClassVar[int]
            ATTACHMENT_EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
            runtimes: _containers.RepeatedScalarFieldContainer[str]
            max_attachments: int
            attachment_max_size: int
            attachment_types: _containers.RepeatedScalarFieldContainer[str]
            attachment_extensions: _containers.RepeatedScalarFieldContainer[str]
            def __init__(self, runtimes: _Optional[_Iterable[str]] = ..., max_attachments: _Optional[int] = ..., attachment_max_size: _Optional[int] = ..., attachment_types: _Optional[_Iterable[str]] = ..., attachment_extensions: _Optional[_Iterable[str]] = ...) -> None: ...
        class File(_message.Message):
            __slots__ = ("types", "extensions", "max_size")
            TYPES_FIELD_NUMBER: _ClassVar[int]
            EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
            MAX_SIZE_FIELD_NUMBER: _ClassVar[int]
            types: _containers.RepeatedScalarFieldContainer[str]
            extensions: _containers.RepeatedScalarFieldContainer[str]
            max_size: int
            def __init__(self, types: _Optional[_Iterable[str]] = ..., extensions: _Optional[_Iterable[str]] = ..., max_size: _Optional[int] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        CODE_FIELD_NUMBER: _ClassVar[int]
        FILE_FIELD_NUMBER: _ClassVar[int]
        name: str
        label: str
        type: Form.Field.Type
        code: Form.Field.Code
        file: Form.Field.File
        def __init__(self, name: _Optional[str] = ..., label: _Optional[str] = ..., type: _Optional[_Union[Form.Field.Type, str]] = ..., code: _Optional[_Union[Form.Field.Code, _Mapping]] = ..., file: _Optional[_Union[Form.Field.File, _Mapping]] = ...) -> None: ...
    class Value(_message.Message):
        __slots__ = ("name", "code", "file")
        class Code(_message.Message):
            __slots__ = ("runtime", "source_url", "attachments")
            RUNTIME_FIELD_NUMBER: _ClassVar[int]
            SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
            ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
            runtime: str
            source_url: str
            attachments: _containers.RepeatedCompositeFieldContainer[Form.Value.File]
            def __init__(self, runtime: _Optional[str] = ..., source_url: _Optional[str] = ..., attachments: _Optional[_Iterable[_Union[Form.Value.File, _Mapping]]] = ...) -> None: ...
        class File(_message.Message):
            __slots__ = ("filename", "data_url")
            FILENAME_FIELD_NUMBER: _ClassVar[int]
            DATA_URL_FIELD_NUMBER: _ClassVar[int]
            filename: str
            data_url: str
            def __init__(self, filename: _Optional[str] = ..., data_url: _Optional[str] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        CODE_FIELD_NUMBER: _ClassVar[int]
        FILE_FIELD_NUMBER: _ClassVar[int]
        name: str
        code: Form.Value.Code
        file: Form.Value.File
        def __init__(self, name: _Optional[str] = ..., code: _Optional[_Union[Form.Value.Code, _Mapping]] = ..., file: _Optional[_Union[Form.Value.File, _Mapping]] = ...) -> None: ...
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.RepeatedCompositeFieldContainer[Form.Field]
    def __init__(self, fields: _Optional[_Iterable[_Union[Form.Field, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/profile.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/vendor/profile.proto\x12\reolymp.vendor\x1a\x1fgoogle/protobuf/timestamp.proto\"\xae\x05\n\x07Profile\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x06status\x18\x02 \x01(\x0e\x32\x1d.eolymp.vendor.Profile.Status\x12\x15\n\rstatus_reason\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\n \x01(\t\x12\x11\n\tlast_name\x18\x0b \x01(\t\x12\x14\n\x0c\x63ompany_name\x18\x10 \x01(\t\x12,\n\x08\x62irthday\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65mail\x18\r \x01(\t\x12\r\n\x05phone\x18\x0e \x01(\t\x12\x0e\n\x06tax_id\x18\x0f \x01(\t\x12\x10\n\x07\x63ountry\x18\xc8\x01 \x01(\t\x12\x0e\n\x05state\x18\xc9\x01 \x01(\t\x12\x14\n\x0bpostal_code\x18\xca\x01 \x01(\t\x12\r\n\x04\x63ity\x18\xcb\x01 \x01(\t\x12\x0e\n\x05line1\x18\xd2\x01 \x01(\t\x12\x0e\n\x05line2\x18\xd3\x01 \x01(\t\x12.\n\ncreated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x93\x01\n\x05Patch\"\x89\x01\n\x05\x46ield\x12\x12\n\x0eUNKNONWN_FIELD\x10\x00\x12\x0e\n\nFIRST_NAME\x10\x01\x12\r\n\tLAST_NAME\x10\x02\x12\x10\n\x0c\x43OMPANY_NAME\x10\x03\x12\x0c\n\x08\x42IRTHDAY\x10\x04\x12\t\n\x05\x45MAIL\x10\x05\x12\t\n\x05PHONE\x10\x06\x12\n\n\x06TAX_ID\x10\x07\x12\x0b\n\x07\x41\x44\x44RESS\x10\x08\"[\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06REVIEW\x10\x02\x12\x0c\n\x08\x41PPROVED\x10\x04\x12\n\n\x06\x41\x43TIVE\x10\x06\x12\x0c\n\x08REJECTED\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_PROFILE']._serialized_start=80
  _globals['_PROFILE']._serialized_end=766
  _globals['_PROFILE_PATCH']._serialized_start=526
  _globals['_PROFILE_PATCH']._serialized_end=673
  _globals['_PROFILE_PATCH_FIELD']._serialized_start=536
  _globals['_PROFILE_PATCH_FIELD']._serialized_end=673
  _globals['_PROFILE_STATUS']._serialized_start=675
  _globals['_PROFILE_STATUS']._serialized_end=766
# @@protoc_insertion_point(module_scope)
